Predictors
==========

.. automodule:: stonesoup.predictor
    :no-members:

.. automodule:: stonesoup.predictor.base
    :show-inheritance:

Kalman
------

.. automodule:: stonesoup.predictor.kalman
    :show-inheritance:

Particle
--------

.. automodule:: stonesoup.predictor.particle
    :show-inheritance:

Ensemble
--------

.. automodule:: stonesoup.predictor.ensemble
    :show-inheritance:

Information
-----------

.. automodule:: stonesoup.predictor.information
    :show-inheritance:

Accumulated State Densities
---------------------------

.. automodule:: stonesoup.predictor.asd
    :show-inheritance:

Categorical
-----------

.. automodule:: stonesoup.predictor.categorical
    :show-inheritance:

Composite
---------

.. automodule:: stonesoup.predictor.composite
    :show-inheritance:
